[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/0.28.2...0.28.3)

### Fixes

- Fixed tag-name output. [0e773ec](https://github.com/callowayproject/bump-my-version/commit/0e773ecc5812a066b8c0f049a597e092722f138b)
    
- Fixed PACKAGE env variable. [76c31c4](https://github.com/callowayproject/bump-my-version/commit/76c31c419759d15d8ea74fce94cee5353056ba76)
    
- Fixed syntax errors in scripts. [56dfac0](https://github.com/callowayproject/bump-my-version/commit/56dfac09a191d3a519bf2de6c0a0b6d0c4e456ba)
    
- Fixes missing runs-on in workflow. [5fe8ce5](https://github.com/callowayproject/bump-my-version/commit/5fe8ce5b1af1d0c915ee7937b664202fec342dca)
    
- Fix: resolve config path to align with the actual repository root. [c872315](https://github.com/callowayproject/bump-my-version/commit/c8723155465cf42d97ef505c54ee983b9880eefb)
    
- Fixed docs. [1d26b55](https://github.com/callowayproject/bump-my-version/commit/1d26b55dd1f37f9559daa6a4ac3a0dbdf167099c)
    
- Fixed doc generation. [aa95762](https://github.com/callowayproject/bump-my-version/commit/aa95762a30648c1afb0e26176041f26a25c26dab)
    
### New

- Added release workflow step. [d56650a](https://github.com/callowayproject/bump-my-version/commit/d56650a26d878e4cfab331004cc7d383bf955131)
    
- Added write permissions for contents in github action. [85f19df](https://github.com/callowayproject/bump-my-version/commit/85f19dfeb7c751fa6ba5a06b79694ca27529da2f)
    
### Other

- Debugging the release workflow. [db2eb9e](https://github.com/callowayproject/bump-my-version/commit/db2eb9ef177d7fcd55c832a3f1f9993b7b19bd4a)
    
- [pre-commit.ci] pre-commit autoupdate. [37c21a4](https://github.com/callowayproject/bump-my-version/commit/37c21a4bc668935a98de931762d1a6b6ffc17311)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.8.2 → v0.8.3](https://github.com/astral-sh/ruff-pre-commit/compare/v0.8.2...v0.8.3)

- Bump actions/setup-python in the github-actions group. [3dd6666](https://github.com/callowayproject/bump-my-version/commit/3dd666668ad099a9ee712bf4679296c7b1df16fb)
    
  Bumps the github-actions group with 1 update: [actions/setup-python](https://github.com/actions/setup-python).


  Updates `actions/setup-python` from 5.1.1 to 5.3.0
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v5.1.1...v5.3.0)

  ---
  **updated-dependencies:** - dependency-name: actions/setup-python
dependency-type: direct:production
update-type: version-update:semver-minor
dependency-group: github-actions

  **signed-off-by:** dependabot[bot] <support@github.com>

### Updates

- Removed debug stuff. [c0e7ad4](https://github.com/callowayproject/bump-my-version/commit/c0e7ad4b84bcac847039b02ed245b3b9b2b37200)
    
